/*
 * $Header: /home/jerenkrantz/tmp/commons/commons-convert/cvs/home/cvs/jakarta-commons//resources/src/test/org/apache/commons/resources/impl/CollectionResourcesBaseTestCase.java,v 1.11 2004/09/07 23:49:47 jmitchell Exp $
 * $Revision: 155432 $
 * $Date: 2005-02-26 08:15:50 -0500 (Sat, 26 Feb 2005) $
 *
 * ====================================================================
 *
 *  Copyright 2003-2004 The Apache Software Foundation
 * 
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 */

package org.apache.commons.resources.impl;

import java.util.ArrayList;
import java.util.List;
import java.util.Locale;

import junit.framework.Test;
import junit.framework.TestSuite;

import org.apache.commons.resources.ResourcesException;
import org.apache.commons.resources.ResourcesKeyException;

/**
 * <p>Unit tests for
 * <code>org.apache.commons.resources.impl.CollectionResourcesBase</code>.
 * </p>
 */
public class CollectionResourcesBaseTestCase extends ResourcesBaseTestCase {


    // ----------------------------------------------------- Instance Variables


    // Base URL of the resource files for the Resources instance to be created
    private static final String BASE = "fixme";


    // ----------------------------------------------------------- Constructors


    public CollectionResourcesBaseTestCase(String name) {
        super(name);
    }


    // --------------------------------------------------- Overall Test Methods


    // Set up instance variables required by this test case
    public void setUp() throws Exception {
        factory = new CollResourcesFactory();
        resources = factory.getResources(NAME, getBase());
    }

    // Return the tests included in this test suite
    public static Test suite() {
        return (new TestSuite(CollectionResourcesBaseTestCase.class));
    }

    // Tear down the instance variables required by this test case
    public void tearDown() {
        resources = null;
        factory = null;
    }

    protected String getBase() throws Exception {
        return BASE;
    }

    // ------------------------------------------------ Individual Test Methods


    // Test retrieving Strings that should be inherited from parent Locales
    public void testInherit() throws Exception {

        Locale locale = null;

        locale = new Locale("en", "US");
        assertEquals("en_US inherit value",
                     "[en] INHERIT",
                     resources.getString("test.inherit", locale, null));

        locale = new Locale("fr", "FR");
        assertEquals("fr_FR inherit value",
                     "[fr] INHERIT",
                     resources.getString("test.inherit", locale, null));

    }


    // Test the getLocaleList() method
    public void testLocaleList() {

        Locale test = null;
        List expected = null;
        CollectionResourcesBase cresources =
            (CollectionResourcesBase) resources;

        test = new Locale("en", "US", "POSIX");
        expected = new ArrayList();
        expected.add(test);
        expected.add(new Locale("en", "US"));
        expected.add(new Locale("en", ""));
        expected.add(new Locale("", ""));
        checkLocaleList(test, expected, cresources.getLocaleList(test));

        test = new Locale("en", "US");
        expected = new ArrayList();
        expected.add(test);
        expected.add(new Locale("en", ""));
        expected.add(new Locale("", ""));
        checkLocaleList(test, expected, cresources.getLocaleList(test));

        test = new Locale("en", "");
        expected = new ArrayList();
        expected.add(test);
        expected.add(new Locale("",""));
        checkLocaleList(test, expected, cresources.getLocaleList(test));

        test = new Locale("", "US", "POSIX");
        expected = new ArrayList();
        expected.add(test);
        expected.add(new Locale("", "US"));
        expected.add(new Locale("", ""));
        checkLocaleList(test, expected, cresources.getLocaleList(test));

        test = new Locale("", "US");
        expected = new ArrayList();
        expected.add(test);
        expected.add(new Locale("", ""));
        checkLocaleList(test, expected, cresources.getLocaleList(test));

    }


    // Test retrieving missing resource keys
    public void testMissing() throws Exception {

        Locale locale = new Locale("en","");
        try {
            resources.setReturnNull(true);
            String value = resources.getString("test.missing", locale, null);
            assertTrue("Should have returned null", value == null);
        } catch (ResourcesException e) {
            fail("Should have returned null");
        }
		
        try {
			resources.setReturnNull(false);
			resources.getString("test.missing", locale, null);
			fail("Should have thrown ResourcesException");
		} catch (ResourcesKeyException e) {
			// Expected result
		}

    }


    // Test retrieving Locale-specific Strings explicitly
    public void testSpecific() throws Exception {

        Locale locale = null;

        locale = new Locale("en", "");
        assertEquals("en specific value",
                     "[en] SPECIFIC",
                     resources.getString("test.specific", locale, null));

        locale = new Locale("en", "US");
        assertEquals("en_US specific value",
                     "[en_US] SPECIFIC",
                     resources.getString("test.specific", locale, null));

        locale = new Locale("fr", "");
        assertEquals("fr specific value",
                     "[fr] SPECIFIC",
                     resources.getString("test.specific", locale, null));

    }


    // ------------------------------------------------------ Protected Methods


    // Check the results of a getLocaleList() operation
    protected void checkLocaleList(Locale test, List expected, List actual) {

        assertEquals("[" + test + "] list length",
                     expected.size(),
                     actual.size());
        for (int i = 0; i < expected.size(); i++) {
            assertEquals("[" + test + "] list contents[" + i + "]",
                         expected.get(i),
                         actual.get(i));
        }

    }


}
